*This file combines Upjohn datasets (exhaustees and Penn Reemployment Bonus) into a single file to be used for severance pay analysis
*Variables defined consistently where available across two datasets, with mean weight of 1

clear
set mem 200m
set more off

***Prepare Penn data
use penn/data/survfile

*Date of first UI payment (in sas date format, can be converted to year via stata year() command)
*Note that this is last date of job, to reduce # of missing obs
gen applic_date = ab_dt

drop race
gen race = 1 if r_ec=="W"
replace race = 2 if r_ec=="B"
replace race = 3 if r_ec=="H"
replace race = 4 if race==.

*Need to construct age manually because it was defined only for demo sample, follow their procedure
drop age
gen age = (preuiend-dob)/365.25
replace age = . if age<15
replace age = int(age)

rename preuiy puihhinc  
*Define indicator for being in demo sample (450 interviewees were not part of demo)
rename dem_inel demstat

gen exprcl_admin = 1 if rcal_xpt=="Y"
replace exprcl_admin = 0 if rcal_xpt=="N"
rename exprec exprcl_survey

*Generate categorical recall variable like recall var in exhaustee dataset
*0 denotes no recall expectation, 1 denotes recall expected with no definite date, and 2 denotes known recall date
gen recall_cat = 0 if exprcl_survey==0
replace recall_cat = 1 if exprcl_survey==1&rcal_dt==.
replace recall_cat = 2 if exprcl_survey==1&rcal_dt~=.

gen exhaustee = bal==0 if bal~=.
rename wages bpearn

gen preui_wageinc = cv1*52

rename seasonal seasind

rename sic sic_admin
rename empsp spouse_employed_at_layoff

rename q6_14 hnp

gen tenure_yrs = preuiwks*7/365.25

rename preind preind_2dig_survey
rename preocc preocc_2dig_survey

rename q1_13 sevpay_yn
rename q1_14 sevpay_amt

gen laidoff = q1_16==1 if q1_16~=.
gen dataset="PENN"
gen st = "PA"

rename numpay wksuipaid_admin
*Note that this measureis very similar to round((mba-bal)/wba)

*Generate lag between job loss and application date since this is not captured in admin wks ui paid measure and this may be endogenous
gen end_date_prejob = seed
replace end_date = q1_7dt if end_date==.
gen wks_to_applic = round((applic_date-end_date_prejob)/7)
replace wks_to_applic = 0 if wks_to_applic<0

*Survey measure: number of weeks from end of pre-ui job to start date of first post-ui job (or interview date for censored obs)
gen dur_survey = round(initdur2)
gen censored_survey = q5_1==0 if dur_survey~=.&q5_1~=.

*Give weight of 1 to non-demo group, because just random sampling there
replace weight = 1 if demstat == 0

#delimit;
keep applic_date exprcl_admin exprcl_survey recall_cat exhaustee bpearn preui_wageinc wba sex age race tg demstat
seasind sic_admin preind_2dig preocc_2dig workexp married spouse_employed kids hnp dropout collgr puihhinc
tenure_yrs sevpay_yn sevpay_amt weight laidoff st dataset
wksuipaid_admin wks_to_applic dur_survey censored_survey;
#delimit cr

save penn_extract, replace
clear


***Prepare exhaustees data
*Have to rely more on survey data here

use exhaustees/data/uivar

*Define date of application for UI benefits
gen applic_date = bybdt

gen exprcl_admin = .
rename exprcll exprcl_survey
rename recall recall_cat

gen exhaustee = xhaustee-1

rename race raw_race
gen race = 1 if raw_race==6
replace race = 2 if raw_race==3
replace race = 3 if raw_race==4
replace race = 4 if race==.

gen tg = .
gen sic_admin = .

rename pu_sic2 preind_2dig_survey
rename pu_soc2 preocc_2dig_survey

*work experience?
gen workexp = .

gen preui_wageinc = weekearn*52

rename ltintrvw married

rename pwrkjobs spouse_employed_at_layoff

rename h3 hnp

rename h4 kids

rename hsdrp dropout

gen collgr = (h2 >= 6 & h2 <= 8) if h2~=.

gen tenure_yrs  = tenure/365.25

rename b25 sevpay_yn

*No sev pay amt data
gen sevpay_amt = .

rename b24 union

egen mean_weight = mean(wts4)
gen weight = wts4/mean_weight

gen wksuipaid_admin = round((mba-rembal)/wba)

*Generate lag between job loss and application date since this is not captured in admin wks ui paid measure and this may be endogenous
gen wks_to_applic = round((applic_date-b4_date)/7)
replace wks_to_applic = 0 if wks_to_applic<0

*Survey measure: number of weeks from end of pre-ui job to start date of first post-ui job (or interview date for censored obs)
gen dur_survey = round(wks2job2) if nojob==0
replace dur_survey = round((intdate - b4_date)/7) if nojob==1
gen censored_survey = nojob if dur_survey~=.

gen dataset="XHAUST"

#delimit;
keep applic_date exprcl_admin exprcl_survey recall_cat exhaustee bpearn preui_wageinc wba sex age race tg
seasind sic_admin preind_2dig preocc_2dig workexp married spouse_employed kids hnp dropout collgr puihhinc
tenure_yrs sevpay_yn sevpay_amt weight laidoff union st dataset
wksuipaid_admin wks_to_applic dur_survey censored_survey ;
#delimit cr

save exhaustees_extract, replace

append using penn_extract

gen male = sex==1 if sex~=.
drop sex

#delimit;
order applic_date exprcl_admin exprcl_survey recall_cat exhaustee bpearn preui_wageinc wba male age race tg demstat
seasind sic_admin preind_2dig preocc_2dig workexp married spouse_employed kids hnp dropout collgr puihhinc
tenure_yrs sevpay_yn sevpay_amt weight laidoff st dataset
wksuipaid_admin wks_to_applic dur_survey censored_survey;
#delimit cr


***Convert all monetary values to real 1990 dollars for consistency with SIPP data
gen year = year(applic_date)
sort year
merge year using ../cpiseries
gen temp = cpi if year==1990
egen cpi1990 = mean(temp)
drop if _merge==2
drop temp _merge
gen cpi_deflator = cpi/cpi1990

#delimit;
foreach X of varlist bpearn preui_wageinc wba puihhinc sevpay_amt {;
rename `X' `X'_nom;
gen `X' = `X'_nom/cpi_deflator;
};
#delimit cr


save pooled_data, replace
clear


*Asset prediction from SIPP
use ../coxtests
keep if _t==1&ui_yn==1&templayoff==0
rename mardum married
gen dropout = ed<12
gen collgr = ed>=16
rename annwg preui_wageinc
reg hh_netliq age preui_wageinc married dropout collgr

use pooled_data, clear
predict hh_netliq_pred

save, replace

*Add in information on waiting periods to correct admin duration measures
*Get this info from z:\research\uilaws\uilaws.xls, cut and paste into waitpers.dta, and merge with statecodes to get two digit abbreviations
gen month = month(applic_date)
gen part = 1 if month<=6
replace part = 2 if month>6&month<.
replace year = 1988 if year~=1988&year~=1989&dataset=="PENN"
replace year = 1998 if year~=1998&year~=1997&dataset=="XHAUST"
replace part = 1 if part==.
sort st year part
merge st year part using waitpers_merged, nokeep
tab _merge
drop _merge month part

gen dur_admin = wksuipaid_admin + waitper


save, replace
